@@ -1,4 +1,4 @@
-__version__ = "2.3.2"
+__version__ = "3.1.0"
 
 ANSWERS_URL = "https://github.com/pyneng/pyneng-course-answers"
 # needed for tasks/tests updates
@@ -24,6 +24,25 @@ TASK_DIRS = [
     "24_oop_inheritance",
     "25_db",
 ]
+TASK_NUMBER_DIR_MAP = {
+    4: "04_data_structures",
+    5: "05_basic_scripts",
+    6: "06_control_structures",
+    7: "07_files",
+    9: "09_functions",
+    11: "11_modules",
+    12: "12_useful_modules",
+    15: "15_module_re",
+    17: "17_serialization",
+    18: "18_ssh_telnet",
+    19: "19_concurrent_connections",
+    20: "20_jinja2",
+    21: "21_textfsm",
+    22: "22_oop_basics",
+    23: "23_oop_special_methods",
+    24: "24_oop_inheritance",
+    25: "25_db",
+}
 
 DB_TASK_DIRS = [
     "task_25_1",
